CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_power.h Source File

CCL

ccl_power.h
Go to the documentation of this file.
1 #pragma once
2
3 #include "ccl_core.h"
4
15 double ccl_linear_matter_power(ccl_cosmology * cosmo, double k, double a,int * status);
16
27 double ccl_nonlin_matter_power(ccl_cosmology * cosmo, double k, double a,int * status);
28
38 double ccl_sigmaR(ccl_cosmology *cosmo, double R, int * status);
39
48 double ccl_sigma8(ccl_cosmology *cosmo, int * status);
ccl_nonlin_matter_power
double ccl_nonlin_matter_power(ccl_cosmology *cosmo, double k, double a, int *status)
Definition: ccl_power.c:1074
ccl_core.h
ccl_sigmaR
double ccl_sigmaR(ccl_cosmology *cosmo, double R, int *status)
Definition: ccl_power.c:1141
ccl_linear_matter_power
double ccl_linear_matter_power(ccl_cosmology *cosmo, double k, double a, int *status)
Definition: ccl_power.c:1042
ccl_sigma8
double ccl_sigma8(ccl_cosmology *cosmo, int *status)
Definition: ccl_power.c:1162
ccl_cosmology
Definition: ccl_core.h:115